<?php
//Rest API
add_action( 'rest_api_init', function () {
	register_rest_route( 'v2', '/ssr_find_all/', array(
		'methods' => WP_REST_Server::ALLMETHODS,
		'callback' => 'ssr_api_ssr_find_all',
        'permission_callback' => 'ssr_get_public_data_permissions_check',
	) );
} );
function ssr_api_ssr_find_all( $request_data ) {
	// if ( !is_user_logged_in() ) {return array( 'success' => false,'message' => 'Authentication ERROR','code' => 404 );}
	$parameters = $request_data->get_params();
	if( !isset( $parameters['postID'] ) || empty( $parameters['postID'] )  || strlen($parameters['postID']) == 0) return array( 'success' => false,'message' => 'registration id not found','code' => 404 );
	
	global $wpdb;
	$sql=$wpdb->prepare( "SELECT * FROM ".$wpdb->prefix.SSR_TABLE." where rid=%s", ssr_needsCleaning($parameters['postID']) );

	$p = $wpdb->get_results($sql);
	return $p ? array( 'success' => true , 0 => $p[0],'code' => 101 ) : array( 'success' => false , 'message' => 'No data','code' => 405 );
}
function ssr_get_public_data_permissions_check() {
    return true;
}
function ssr_get_private_data_permissions_check() {
	return current_user_can( 'manage_options' ) ? true : false;
}



function ssr_clean_arr($arr){
	$newArr =[];$search="nonce";
	foreach($arr as $key => $val){
        if(!preg_match("/{$search}/i", $key)) {
            $newArr[$key]= ssr_needsCleaning($val);
        }
	}
	return $newArr;
}

add_action( 'rest_api_init', function () {
	register_rest_route( 'v2', '/ssr_add_data/', array(
		'methods' => WP_REST_Server::CREATABLE,
		'callback' => 'ssr_update_st_submit',
        'permission_callback' => 'ssr_get_private_data_permissions_check',
	) );
});


function ssr_update_st_submit( $request_data ) {
	$parameters = $request_data->get_params();
	if( !isset( $parameters['rid'] ) || empty( $parameters['rid'] )  || strlen($parameters['rid']) == 0) return array( 'success' => false,'message' => 'registration id not found','code' => 404 );
	global $wpdb;
    if (isset($parameters['rid'])) {
		$data= [ 'rid' => $parameters['rid'], 'roll' => $parameters['roll'], 'stdname' => $parameters['stdname'], 'fathersname' => $parameters['fathersname'], 'pyear' => $parameters['pyear'], 'cgpa' => $parameters['cgpa'], 'subject' => $parameters['subject'], 'dob' => $parameters['dob'], 'gender' => $parameters['gender'], 'address' => $parameters['address'], 'mnam' => $parameters['mnam'], 'c1' => $parameters['c1'], 'c2' => $parameters['c2'], 'image' => $parameters['image']];
		$wpdb->delete( $wpdb->prefix.SSR_TABLE, array( 'rid' => ssr_needsCleaning($parameters['rid'])) );
		$p = $wpdb->insert($wpdb->prefix.SSR_TABLE, ssr_clean_arr($data) , array( '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s' ));
    }
$student_count =$wpdb->get_var( "SELECT COUNT(*) FROM ".$wpdb->prefix.SSR_TABLE );
return $p ? array( 'success' => true , 'count' => $student_count,'code' => 101 ) : array( 'success' => false , 'message' => 'Not saved, please email saadvi@gmail.com for submit this error report','code' => 406 );
	// if ($wpdb->last_error) {
  // die('error=' . var_dump($wpdb->last_query) . ',' . var_dump($wpdb->error));
// }
die();
}


add_action( 'rest_api_init', function () {
	register_rest_route( 'v2', '/ssr_delete_data/', array(
		'methods' => WP_REST_Server::CREATABLE,
		'callback' => 'ssr_delete_data_now',
        'permission_callback' => 'ssr_get_private_data_permissions_check',
	) );
});


function ssr_delete_data_now( $request_data ) {
	$parameters = $request_data->get_params();
	if( !isset( $parameters['rid'] ) || empty( $parameters['rid'] )  || strlen($parameters['rid']) == 0) return array( 'success' => false,'message' => 'registration id not found','code' => 404 );
	global $wpdb;
    if (isset($parameters['rid'])) {
		$p=$wpdb->delete( $wpdb->prefix.SSR_TABLE, array( 'rid' => ssr_needsCleaning($parameters['rid'])) );
    }
$student_count =$wpdb->get_var( "SELECT COUNT(*) FROM ".$wpdb->prefix.SSR_TABLE );
return $p ? array( 'success' => true , 'count' => $student_count,'code' => 101 ) : array( 'success' => false , 'message' => 'Not deleted, please email saadvi@gmail.com for submit this error report','code' => 407 );
die();
}




add_action( 'rest_api_init', function () {
	register_rest_route( 'v2', '/ssr_text_option/', array(
		'methods' => WP_REST_Server::CREATABLE,
		'callback' => 'ssr_update_text_option',
        'permission_callback' => 'ssr_get_private_data_permissions_check',
	) );
});


function ssr_update_text_option( $request_data ) {
	$parameters = $request_data->get_params();
	if( !isset( $parameters['optionId'] ) || empty( $parameters['optionId'] )  || strlen($parameters['optionId']) == 0) return array( 'success' => false,'message' => 'option Id not found','code' => 404 );
	if( !isset( $parameters['optionValue'] ) || empty( $parameters['optionValue'] )  || strlen($parameters['optionValue']) == 0) return array( 'success' => false,'message' => 'option Value not found','code' => 404 );
	$text = sanitize_text_field( ssr_needsCleaning($parameters['optionValue']) );
	$oldval=esc_attr( get_option('ssr_settings_ssr_item'.intval($parameters['optionId']) ));
	return array( 'success' => update_option('ssr_settings_ssr_item'.intval($parameters['optionId']), $text) , 'text' => $text ,'oldval'=>$oldval, 'option' => 'ssr_settings_ssr_item'.intval($parameters['optionId']), 'code' => 701 );
}

add_action( 'rest_api_init', function () {
	register_rest_route( 'v2', '/ssr_tick_option/', array(
		'methods' => WP_REST_Server::CREATABLE,
		'callback' => 'ssr_update_tick_option',
        'permission_callback' => 'ssr_get_private_data_permissions_check',
	) );
});


function ssr_update_tick_option( $request_data ) {
	$parameters = $request_data->get_params();
	if( !isset( $parameters['optionId'] ) || empty( $parameters['optionId'] )  || strlen($parameters['optionId']) == 0) return array( 'success' => false,'message' => 'option Id not found','code' => 404 );
	if( !isset( $parameters['optionValue'] )  || strlen($parameters['optionValue']) == 0) return array( 'success' => false,'message' => 'option Value not found','code' => 404 );
	delete_option('checkedssr_item'.intval($parameters['optionId']));
	return array( 'success' => add_option('checkedssr_item'.intval($parameters['optionId']), intval($parameters['optionValue'])) ,'code' => 702 );
}